@@ -141,6 +141,12 @@ class _AbstractHMM(BaseEstimator):
             Number of states in the model.
         algorithm : {"viterbi", "map"}, optional
             Decoder algorithm.
+
+            - "viterbi": finds the most likely sequence of states, given all
+              emissions.
+            - "map" (also known as smoothing or forward-backward): finds the
+              sequence of the individual most-likely states, given all
+              emissions.
         random_state: RandomState or an int seed, optional
             A random number generator instance.
         n_iter : int, optional
@@ -302,8 +308,14 @@ class _AbstractHMM(BaseEstimator):
         lengths : array-like of integers, shape (n_sequences, ), optional
             Lengths of the individual sequences in ``X``. The sum of
             these should be ``n_samples``.
-        algorithm : string
-            Decoder algorithm. Must be one of "viterbi" or "map".
+        algorithm : {"viterbi", "map"}, optional
+            Decoder algorithm.
+
+            - "viterbi": finds the most likely sequence of states, given all
+              emissions.
+            - "map" (also known as smoothing or forward-backward): finds the
+              sequence of the individual most-likely states, given all
+              emissions.
             If not given, :attr:`decoder` is used.
 
         Returns
@@ -546,9 +558,11 @@ class _AbstractHMM(BaseEstimator):
         s = getattr(self, name).sum(axis=-1)
         if not np.allclose(s, 1):
             raise ValueError(
-                f"{name} must sum to 1 (got {s:.4f})" if s.ndim == 0 else
-                f"{name} rows must sum to 1 (got {s})" if s.ndim == 1 else
-                "Expected 1D or 2D array")
+                f"{name} must sum to 1 (got {s:.4f})"
+                if s.ndim == 0
+                else f"{name} rows must sum to 1 (got row sums of {s})"
+                    if s.ndim == 1
+                    else "Expected 1D or 2D array")
 
     def _check(self):
         """
@@ -809,6 +823,12 @@ class BaseHMM(_AbstractHMM):
             of the transition probabilities :attr:`transmat_`.
         algorithm : {"viterbi", "map"}, optional
             Decoder algorithm.
+
+            - "viterbi": finds the most likely sequence of states, given all
+              emissions.
+            - "map" (also known as smoothing or forward-backward): finds the
+              sequence of the individual most-likely states, given all
+              emissions.
         random_state: RandomState or an int seed, optional
             A random number generator instance.
         n_iter : int, optional
@@ -929,9 +949,11 @@ class BaseHMM(_AbstractHMM):
         s = getattr(self, name).sum(axis=-1)
         if not np.allclose(s, 1):
             raise ValueError(
-                f"{name} must sum to 1 (got {s:.4f})" if s.ndim == 0 else
-                f"{name} rows must sum to 1 (got {s})" if s.ndim == 1 else
-                "Expected 1D or 2D array")
+                f"{name} must sum to 1 (got {s:.4f})"
+                if s.ndim == 0
+                else f"{name} rows must sum to 1 (got row sums of {s})"
+                    if s.ndim == 1
+                    else "Expected 1D or 2D array")
 
     def _check(self):
         """
@@ -1002,6 +1024,7 @@ class BaseHMM(_AbstractHMM):
         n_params = sum(self._get_n_fit_scalars_per_param().values())
         return -2 * self.score(X, lengths=lengths) + n_params * np.log(len(X))
 
+
 _BaseHMM = BaseHMM  # Backcompat name, will be deprecated in the future.
 
 
