@@ -82,6 +82,12 @@ class CategoricalHMM(_emissions.BaseCategoricalHMM, BaseHMM):
         algorithm : {"viterbi", "map"}, optional
             Decoder algorithm.
 
+            - "viterbi": finds the most likely sequence of states, given all
+              emissions.
+            - "map" (also known as smoothing or forward-backward): finds the
+              sequence of the individual most-likely states, given all
+              emissions.
+
         random_state: RandomState or an int seed, optional
             A random number generator instance.
 
@@ -239,6 +245,12 @@ class GaussianHMM(_emissions.BaseGaussianHMM, BaseHMM):
         algorithm : {"viterbi", "map"}, optional
             Decoder algorithm.
 
+            - "viterbi": finds the most likely sequence of states, given all
+              emissions.
+            - "map" (also known as smoothing or forward-backward): finds the
+              sequence of the individual most-likely states, given all
+              emissions.
+
         random_state: RandomState or an int seed, optional
             A random number generator instance.
 
@@ -298,7 +310,7 @@ class GaussianHMM(_emissions.BaseGaussianHMM, BaseHMM):
         if self._needs_init("m", "means_"):
             kmeans = cluster.KMeans(n_clusters=self.n_components,
                                     random_state=self.random_state,
-                                    n_init=1)  # sklearn <1.4 backcompat.
+                                    n_init=10)  # sklearn <1.4 backcompat.
             kmeans.fit(X)
             self.means_ = kmeans.cluster_centers_
         if self._needs_init("c", "covars_"):
@@ -469,6 +481,12 @@ class GMMHMM(_emissions.BaseGMMHMM):
         algorithm : {"viterbi", "map"}, optional
             Decoder algorithm.
 
+            - "viterbi": finds the most likely sequence of states, given all
+              emissions.
+            - "map" (also known as smoothing or forward-backward): finds the
+              sequence of the individual most-likely states, given all
+              emissions.
+
         random_state: RandomState or an int seed, optional
             A random number generator instance.
 
@@ -844,6 +862,12 @@ class MultinomialHMM(_emissions.BaseMultinomialHMM):
         algorithm : {"viterbi", "map"}, optional
             Decoder algorithm.
 
+            - "viterbi": finds the most likely sequence of states, given all
+              emissions.
+            - "map" (also known as smoothing or forward-backward): finds the
+              sequence of the individual most-likely states, given all
+              emissions.
+
         random_state: RandomState or an int seed, optional
             A random number generator instance.
 
@@ -967,6 +991,12 @@ class PoissonHMM(_emissions.BasePoissonHMM):
         algorithm : {"viterbi", "map"}, optional
             Decoder algorithm.
 
+            - "viterbi": finds the most likely sequence of states, given all
+              emissions.
+            - "map" (also known as smoothing or forward-backward): finds the
+              sequence of the individual most-likely states, given all
+              emissions.
+
         random_state: RandomState or an int seed, optional
             A random number generator instance.
 
