@@ -89,6 +89,12 @@ class VariationalCategoricalHMM(BaseCategoricalHMM, VariationalBaseHMM):
         algorithm : {"viterbi", "map"}, optional
             Decoder algorithm.
 
+            - "viterbi": finds the most likely sequence of states, given all
+              emissions.
+            - "map" (also known as smoothing or forward-backward): finds the
+              sequence of the individual most-likely states, given all
+              emissions.
+
         random_state: RandomState or an int seed, optional
             A random number generator instance.
 
@@ -382,6 +388,12 @@ class VariationalGaussianHMM(BaseGaussianHMM, VariationalBaseHMM):
         algorithm : {"viterbi", "map"}, optional
             Decoder algorithm.
 
+            - "viterbi": finds the most likely sequence of states, given all
+              emissions.
+            - "map" (also known as smoothing or forward-backward): finds the
+              sequence of the individual most-likely states, given all
+              emissions.
+
         random_state: RandomState or an int seed, optional
             A random number generator instance.
 
